import { prependForwardSlash } from "../core/path.js";
function createCollectionToGlobResultMap({
  globResult,
  contentDir
}) {
  const collectionToGlobResultMap = {};
  for (const key in globResult) {
    const keyRelativeToContentDir = key.replace(new RegExp(`^${contentDir}`), "");
    const segments = keyRelativeToContentDir.split("/");
    if (segments.length <= 1)
      continue;
    const collection = segments[0];
    const entryId = segments.slice(1).join("/");
    collectionToGlobResultMap[collection] ?? (collectionToGlobResultMap[collection] = {});
    collectionToGlobResultMap[collection][entryId] = globResult[key];
  }
  return collectionToGlobResultMap;
}
function createGetCollection({
  collectionToEntryMap
}) {
  return async function getCollection(collection, filter) {
    const lazyImports = Object.values(collectionToEntryMap[collection] ?? {});
    const entries = Promise.all(
      lazyImports.map(async (lazyImport) => {
        const entry = await lazyImport();
        return {
          id: entry.id,
          slug: entry.slug,
          body: entry.body,
          collection: entry.collection,
          data: entry.data
        };
      })
    );
    if (typeof filter === "function") {
      return (await entries).filter(filter);
    } else {
      return entries;
    }
  };
}
function createGetEntry({
  collectionToEntryMap
}) {
  return async function getEntry(collection, entryId) {
    var _a;
    const lazyImport = (_a = collectionToEntryMap[collection]) == null ? void 0 : _a[entryId];
    if (!lazyImport)
      throw new Error(`Ah! ${entryId}`);
    const entry = await lazyImport();
    return {
      id: entry.id,
      slug: entry.slug,
      body: entry.body,
      collection: entry.collection,
      data: entry.data
    };
  };
}
function createCollectionToPaths({
  getCollection
}) {
  return async function collectionToPaths(collection) {
    const entries = await getCollection(collection);
    return entries.map((entry) => ({
      params: { slug: entry.slug },
      props: entry
    }));
  };
}
function createRenderEntry({
  collectionToRenderEntryMap
}) {
  return async function renderEntry(entry) {
    var _a;
    const lazyImport = (_a = collectionToRenderEntryMap[entry.collection]) == null ? void 0 : _a[entry.id];
    if (!lazyImport)
      throw new Error(`${String(entry.collection)} \u2192 ${String(entry.id)} does not exist.`);
    const mod = await lazyImport();
    if (Array.isArray(mod == null ? void 0 : mod.collectedLinks) && "links" in (this ?? {})) {
      for (const link of mod.collectedLinks) {
        this.links.add({
          props: { rel: "stylesheet", href: prependForwardSlash(link) },
          children: ""
        });
      }
    }
    if (Array.isArray(mod == null ? void 0 : mod.collectedStyles) && "styles" in (this ?? {})) {
      for (const style of mod.collectedStyles) {
        this.styles.add({
          props: {},
          children: style
        });
      }
    }
    if (!mod._internal && entry.id.endsWith(".mdx")) {
      throw new Error(
        `[Content] Failed to render MDX entry. Try installing @astrojs/mdx@next--content-schemas`
      );
    }
    return {
      Content: mod.Content,
      headings: mod.getHeadings(),
      injectedFrontmatter: mod._internal.injectedFrontmatter
    };
  };
}
export {
  createCollectionToGlobResultMap,
  createCollectionToPaths,
  createGetCollection,
  createGetEntry,
  createRenderEntry
};
